@@ -1,7 +1,14 @@
+#!/usr/bin/env -S uv run --script
+# /// script
+# requires-python = ">=3.13"
+# dependencies = [
+#     "pygments",
+#     "pystache",
+# ]
+# ///
+import argparse
 import functools
 import importlib
-import json
-import os
 import re
 import sys
 import types
@@ -127,7 +134,7 @@ def translate_rules(rules):
                 regex = xml_regex(regex)
             elif isinstance(regex, pygments_lexer.words):
                 regex = xml_string('%s(%s)%s' % (regex.prefix,
-                                      '|'.join(w for w in regex.words),
+                                      '|'.join(re.escape(w) for w in regex.words),
                                       regex.suffix))
             else:
                 raise ValueError('expected regex string but got %r' % regex)
@@ -169,7 +176,11 @@ class TemplateView(object):
 
 
 def main():
-    package_name, symbol_name = sys.argv[1].rsplit(sep=".", maxsplit=1)
+    parser = argparse.ArgumentParser( prog='pygments2chroma_xml.py', description='Converts pygments RegexLexer classes to chroma xml grammar definitions.')
+    parser.add_argument('lexer_class', type=str, help="The class name of the pygments lexer, like: 'pygments.lexers.jvm.KotlinLexer'.")
+    args = parser.parse_args()
+
+    package_name, symbol_name = args.lexer_class.rsplit(sep=".", maxsplit=1)
 
     package = importlib.import_module(package_name)
 
