@@ -23,17 +23,17 @@ func TestCompileAllRegexes(t *testing.T) {
 	for _, lexer := range lexers.GlobalLexerRegistry.Lexers {
 		it, err := lexer.Tokenise(nil, "")
 		assert.NoError(t, err, "%s failed", lexer.Config().Name)
-		err = formatters.NoOp.Format(io.Discard, styles.SwapOff, it)
+		err = formatters.NoOp.Format(io.Discard, styles.Get("swapoff"), it)
 		assert.NoError(t, err, "%s failed", lexer.Config().Name)
 	}
 }
 
 func TestGet(t *testing.T) {
 	t.Run("ByName", func(t *testing.T) {
-		assert.Equal(t, lexers.Get("xml"), lexers.GlobalLexerRegistry.Get("XML"))
+		assert.True(t, lexers.Get("xml") == lexers.GlobalLexerRegistry.Get("XML"))
 	})
 	t.Run("ByAlias", func(t *testing.T) {
-		assert.Equal(t, lexers.Get("as"), lexers.GlobalLexerRegistry.Get("Actionscript"))
+		assert.True(t, lexers.Get("as") == lexers.GlobalLexerRegistry.Get("Actionscript"))
 	})
 	t.Run("ViaFilename", func(t *testing.T) {
 		expected := lexers.Get("XML")
@@ -44,6 +44,19 @@ func TestGet(t *testing.T) {
 	})
 }
 
+func TestAliases(t *testing.T) {
+	t.Run("UseNameIfNoAliases", func(t *testing.T) {
+		expected := lexers.GlobalLexerRegistry.Aliases(false)
+		actual := lexers.Aliases(false)
+		assert.Equal(t, expected, actual)
+	})
+	t.Run("SkipIfNoAliases", func(t *testing.T) {
+		expected := lexers.GlobalLexerRegistry.Aliases(true)
+		actual := lexers.Aliases(true)
+		assert.Equal(t, expected, actual)
+	})
+}
+
 func TestGlobs(t *testing.T) {
 	filename := "main.go"
 	for _, lexer := range lexers.GlobalLexerRegistry.Lexers {
@@ -60,7 +73,7 @@ func TestGlobs(t *testing.T) {
 }
 
 func BenchmarkGet(b *testing.B) {
-	for i := 0; i < b.N; i++ {
+	for range b.N {
 		lexers.Get("go")
 	}
 }
